<%--<?xml version="1.0" encoding="ISO-8859-1" ?>--%>
<%--<%@ page language="java" contentType="text/html; charset=ISO-8859-1" pageEncoding="ISO-8859-1"%>--%>

<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/functions" prefix="fn" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/fmt" prefix="fmt" %>
<%@ taglib uri="http://displaytag.sf.net" prefix="dt" %>


<c:import url="template_header.jsp" >
	<c:param name="title">Documentation</c:param>
</c:import>

<ol class="breadcrumb">
	<li><a href="${pageContext.request.contextPath}/index.jsp">Home</a></li>
	<li><a href="man_docs.jsp">Documentation</a></li>
	<li class="active"><a href="man_server_dev.jsp">Develop JABAWS</a></li>
</ol>
<div class="row">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Using JABAWS From Your Program</h1>
			</div>
			<div class="panel-body">
				<!--<h4>JABAWS Server Virtual Appliance</h4>-->
				<ul>
					<li><a href="#wsfunctions">Web services functions overview </a></li>
					<li><a href="#templatestr">The template client structure</a></li>
					<li><a href="#connectto">Connecting to JABAWS</a></li>
					<li><a href="#validnames">Valid JABAWS service names and WSDL files</a></li>
					<li><a href="#defalign">Aligning sequences</a></li>
					<li><a href="#checkresults">Checking the status of the calculation </a></li>
					<li><a href="#presetalign">Aligning with presets</a></li>
					<li><a href="#customalign">Aligning with custom parameters</a></li>
					<li><a href="#writingaltofile">Writing alignments to a file</a></li>
					<li><a href="#compex">A complete client example </a></li>
					<li><a href="#buildart">Building web services artifacts</a></li>
				</ul>
				<!--<p class="justify">-->
				<!--</p>-->
			</div>
		</div>
	</div>
</div>

<div class="row" id="wsfunctions">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Web services functions overview</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					All JABA multiple sequence alignment web services comply to the same
					interface, thus the function described below are available from all the services.
				</p>
				<strong>Functions for initiating the alignment </strong>
				<pre><code class="java">String id = align(List&lt;FastaSequence&gt; list)
String id = customAlign(List&lt;FastaSequence&gt; sequenceList, List&lt;Option&gt; optionList)
String id = presetAlign(List&lt;FastaSequence&gt; sequenceList, Preset preset)</code></pre>

				<strong>Functions pertaining to job monitoring and control</strong><br />
				<pre><code class="java">JobStatus status = getJobStatus(String id)
Alignment al = getResult(String id)
boolean cancelled = cancelJob(String id)
ChunkHolder chunk = pullExecStatistics(String id, long marker)</code></pre>
				<strong>Functions relating to service features discovery</strong><br />
				<pre><code class="java">RunnerConfig rc = getRunnerOptions()
Limit limit = getLimit(String name)
LimitsManager lm = getLimits()
PresetManager pm = getPresets()</code></pre>
				<p class="justify">
					Please refer to a <a href="dm_javadoc/compbio/data/msa/MsaWS.html">data model
					javadoc</a> for a detailed description of each methods.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="templatestr">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Structure of the template command line client</h1>
			</div>
			<div class="panel-body">
				<table class="table">
					<tr>
						<td style="width:19%"><strong>Packages</strong></td>
						<td style="width:81%"><strong>Classes and Interfaces </strong></td>
					</tr>
					<tr>
						<td>compbio.data.msa </td>
						<td>MsaWS the interface for all multiple sequence alignment web services </td>
					</tr>
					<tr>
						<td>compbio.data.sequence</td>
						<td>JABAWS data types </td>
					</tr>
					<tr>
						<td>compbio.metadata</td>
						<td>JABAWS meta data types </td>
					</tr>
					<tr>
						<td>compbio.ws.client</td>
						<td>JABAWS command line client </td>
					</tr>
				</table>
				<p class="justify">
					Additional utility libraries that this client depend upon is the
					compbio-util-1.3.jar and compbio-annotation-1.0.jar.
				</p>
				<p class="justify">
					Please refer to a <a href="dm_javadoc/index.html">data model javadoc</a>
					for a detailed description of each class and its methods.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="connectto">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Connecting to JABAWS</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					For a complete working example of JABAWS command line client please see
					compbio.ws.client.Jws2Client class. JABAWS command line client
					source code is available from the
					<a href="http://gjb-www-1.cluster.lifesci.dundee.ac.uk:8086/jabaws-dev">download page</a>.
					Please note that for now all
					the examples are in Java, other languages will follow if there is sufficient demand.
				</p>
				<p class="justify">
					Download a binary JABAWS client. Add the client to the class path. The following
					code excerpt will connect your program to Clustal
					web service deployed in the University of Dundee.
				</p>
				<pre><code class="java">import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
// (...)
String qualifiedName = &quot;http://msa.data.compbio/01/01/2010/&quot;;
URL url = new URL(&quot;http://www.compbio.dundee.ac.uk/jabaws/ClustalWS?wsdl&quot;);
QName qname = new QName(, &quot;ClustalWS&quot;);
Service serv = Service.create(url, qname);
MsaWS msaws = serv.getPort(new QName(qualifiedName, &quot;ClustalWSPort&quot;),
MsaWS.class);</code></pre>
				<p>Line 1 makes a qualified name for JABA web services.</p>
				<p>Line 2 constructs the URL to the web services WSDL.</p>
				<p>Line 3 makes a qualified name instance for Clustal JABA web service.</p>
				<p>Line 4 creates a service instance.</p>
				<p>Line 5 makes a connection to the server.</p>
				<p>A more generic connection method would look like this</p>

				<pre><code class="java">import java.net.URL;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import compbio.ws.client.Services
// (...)
String qualifiedServiceName = &quot;http://msa.data.compbio/01/01/2010/&quot;;
String host = &quot;http://www.compbio.dundee.ac.uk/jabaws&quot;;
// In real life the service name can come from args
Services clustal = Services.ClustalWS;
URL url = new URL(host + &quot;/&quot; + clustal.toString() + &quot;?wsdl&quot;);
QName qname = new QName(qualifiedServiceName, clustal.toString());
Service serv = Service.create(url, qname);
MsaWS msaws = serv.getPort(new QName(qualifiedServiceName, clustal + &quot;Port&quot;), MsaWS.class);</code></pre>

				<p class="justify">
					Where Services is enumeration of JABAWS web services. All JABAWS multiple
					sequence alignment methods confirm to
					MsaWS specification, thus from the caller point of view all JABAWS web
					services can be represented by MsaWS
					interface. The full documentation of MsaWS functions is available from
					the <a href="dm_javadoc/compbio/data/msa/MsaWS.html">javadoc</a>.
				</p>

				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="validnames">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Valid JABAWS service names and WSDL files</h1>
			</div>
			<div class="panel-body">
				<p>Multiple sequence alignment services</p>
				<ul><li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/ClustalOWS?wsdl">ClustalOWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/ClustalOWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/ClustalWS?wsdl">ClustalWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/ClustalWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/MuscleWS?wsdl">MuscleWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/MuscleWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/MafftWS?wsdl">MafftWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/MafftWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/TcoffeeWS?wsdl">TcoffeeWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/TcoffeeWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/ProbconsWS?wsdl">ProbconsWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/ProbconsWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/MSAprobsWS?wsdl">MSAprobsWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/MSAprobsWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/GLprobsWS?wsdl">GLprobsWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/GLprobsWS?wsdl) </li>
				</ul>
				<p>Protein disorder prediction services</p>
				<ul>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/IUPredWS?wsdl">IUPredWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/IUPredWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/GlobPlotWS?wsdl">GlobPlotWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/GlobPlotWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/DisemblWS?wsdl">DisemblWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/DisemblWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/JronnWS?wsdl">JronnWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/JronnWS?wsdl) </li>
				</ul>
				<p>Amino acid conservation service</p>
				<ul>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/AAConWS?wsdl">AAConWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/AAConWS?wsdl) </li>
				</ul>
				<p>Protein and RNA Secondary Structure Prediction</p>
				<ul>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/JpredWS?wsdl">JpredWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/JpredWS?wsdl) </li>
					<li><a href="http://www.compbio.dundee.ac.uk/jabaws-dev/RNAalifoldWS?wsdl">RNAalifoldWS</a> (http://www.compbio.dundee.ac.uk/jabaws-dev/RNAalifoldWS?wsdl) </li>
				</ul>
				<p class="justify">
					Please replace <em2>http://www.compbio.dundee.ac.uk/</em2> with your JABAWS instance host name, and
					<em2>jabaws</em2> with your JABAWS context name to access your local version of JABAWS web services.
					For example <em2>http://localhost:8080/jabaws</em2> would be a valid URL for the default Apache-Tomcat
					installation and jabaws.war file deployment.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="defalign">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Aligning sequences</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					Given that <em2>msaws</em2> is web service proxy, created as described in &quot;Connecting to JABAWS&quot;
					section, the actual alignment can be obtained as follows:
				</p>
				<pre><code class="java">List&lt;FastaSequence&gt; fastalist = SequenceUtil.readFasta(new FileInputStream(file));
String jobId = msaws.align(fastalist);
Alignment alignment = msaws.getResult(jobId);</code></pre>

				<p>Line  one loads FASTA sequence from the file.</p>
				<p>Line two submits them to web service represented by msaws proxy.</p>
				<p class="justify">
					Line three retrieves the alignment from a web service. This line will block the execution until the result is available.
					Use this with caution. In general, you should make sure that the calculation has been completed before attempting
					retrieving results. This is to avoid keeping the connection to the server on hold for a prolonged periods of time.
					While this may be ok with your local server, our public server
					(<a href="http://www.compbio.dundee.ac.uk/jabaws">www.compbio.dundee.ac.uk/jabaws</a>) will not let you hold the connection
					for longer than 10 minutes. This is done to prevent excessive load on the server. The next section describes how to check
					the status of the calculation.<br />
					Methods and classes mentioned in the excerpt are available from the JABAWS client library.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="checkresults">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Checking the status of the calculation</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					You may have noticed that there was no pause between submitting the job and retrieving of the results. This is
					because <em2>getResult(jobId)</em2> method block the processing until the calculation is completed.
					However, taking into account that the connection holds server resources, our public server
					(<a href="http://www.compbio.dundee.ac.uk/jabaws">www.compbio.dundee.ac.uk/jabaws</a>) is configured to reset the
					connection after 10 minutes of waiting. To work around the connection reset you are encouraged to check whether the
					calculation has been completed before accessing the results. You can do it like this:
				</p>
				<pre><code class="java">while (msaws.getJobStatus(jobId) != JobStatus.FINISHED) {
&nbsp;&nbsp;&nbsp;&nbsp;Thread.sleep(2000); // wait two  seconds, then recheck the status
}</code></pre>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="presetalign">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Aligning with presets</h1>
			</div>
			<div class="panel-body">
				 <pre><code class="java">PresetManager presetman = msaws.getPresets();
Preset preset = presetman.getPresetByName(presetName);
List&lt;FastaSequence&gt; fastalist = SequenceUtil.readFasta(new FileInputStream(file));
String jobId = msaws.presetAlign(fastalist, preset);
Alignment alignment = msaws.getResult(jobId);</code></pre>
				<p>Line one obtains the lists of presets supported by a web service.</p>
				<p>Line two return a particular Preset by its name.</p>
				<p>
					Lines three to five  are doing the same job as in the first <a href="#defalign">
					aligning sequences example</a>.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="customalign">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Aligning with custom parameters</h1>
			</div>
			<div class="panel-body">
				<pre><code class="java">RunnerConfig options = msaws.getRunnerOptions();
Argument matrix = options.getArgument(&quot;MATRIX&quot;);
matrix.setValue(&quot;PAM300&quot;);
Argument gapopenpenalty = options.getArgument(&quot;GAPOPEN&quot;);
gapopenpenalty.setValue(&quot;20&quot;);
List&lt;Argument&gt; arguments = new ArrayList&lt;Argument&gt;();
arguments.add(matrix); arguments.add(gapopenpenalty);
List&lt;FastaSequence&gt; fastalist = SequenceUtil.readFasta(new FileInputStream(file));
String jobId = msaws.customAlign(fastalist, arguments);
Alignment alignment = msaws.getResult(jobId);</code></pre>

				<p>Line one obtains the <em2>RunnerConfig</em2> object that holds information on
					supported parameters and their values</p>
				<p>Line two retrieve a particular parameter from the holder by its name.</p>
				<p>Lines three sets a value to this parameter which will be used in the calculation. </p>
				<p>Line four and five do the same but for another parameter.</p>
				<p>Line six makes a List to hold the parameters.</p>
				<p>Line seven puts the parameters into that list.</p>
				<p>Line eight and ten is the same as in previous examples.</p>
				<p>Line nine submit an alignment request with the sequences and the parameters.</p>
				<p class="justify">The names of all the parameters supported by a web service e.g. &quot;PAM300&quot; can be obtained
					using <em2>options.getArguments()</em2>method. Further details on the methods
					available from <em2>RunnerConfig</em2> object are available from the
					<a href="dm_javadoc/index.html">javadoc</a>.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="writingaltofile">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Writing alignments to a file</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					There is a utility method in the client library that does exactly that.
				</p>
				<pre><code class="java">Alignment alignment = align(...)
FileOutputStream outStream = new FileOutputStream(file);
ClustalAlignmentUtil.writeClustalAlignment(outStream, align);</code></pre>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="compex">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">A complete client example</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					Finally, a complete example of the program that connects to JABAWS Clustal
					service and aligns sequences using
					one of the  Clustal web service presets. There is also a
					<a href="2.1/Example_template.pdf">PDF version</a> of
					this example with syntax highlighted. The text comments are commented by block
					style comments e.g. /* comment */,
					the alternatives given in the code are line commented // comment. You may want
					to remove line style comments to
					test alternatives of the functions. All you need for this to work is a
					<a href="http://gjb-www-1.cluster.lifesci.dundee.ac.uk:8086/jabaws-dev/get?id=min-jaba-client-2.0.jar">JABAWS binary client</a>.
					Please make sure that the client is in the Java class path before running this example.
				</p>
				<pre><code class="java">
import java.io.ByteArrayInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.net.URL;
import java.util.List;

import javax.xml.namespace.QName;
import javax.xml.ws.Service;

import compbio.data.msa.MsaWS;
import compbio.data.sequence.Alignment;
import compbio.data.sequence.FastaSequence;
import compbio.data.sequence.SequenceUtil;
import compbio.metadata.JobSubmissionException;
import compbio.metadata.LimitExceededException;
import compbio.metadata.Preset;
import compbio.metadata.PresetManager;
import compbio.metadata.ResultNotAvailableException;
import compbio.metadata.UnsupportedRuntimeException;
import compbio.metadata.WrongParameterException;

public class Example {

/*
 * Input sequences for alignment
 */
static final String input = &quot;&gt;Foo\r\n&quot;
		+ &quot;MTADGPRELLQLRAAVRHRPQDFVAWLMLADAELGMGDTTAGEMAVQRGLALHPGHPEAVARLGR&quot;
		+ &quot;VRWTQQRHAEAAVLLQQASDAAPEHPGIALWLGHALEDAGQAEAAAAAYTRAHQLLPEEPYITAQ&quot;
		+ &quot;LLNWRRRLCDWRALDVLSAQVRAAVAQGVGAVEPFAFLSEDASAAEQLACARTRAQAIAASVRPL&quot;
		+ &quot;APTRVRSKGPLRVGFVSNGFGAHPTGLLTVALFEALQRRQPDLQMHLFATSGDDGSTLRTRLAQA&quot;
		+ &quot;STLHDVTALGHLATAKHIRHHGIDLLFDLRGWGGGGRPEVFALRPAPVQVNWLAYPGTSGAPWMD&quot;
		+ &quot;YVLGDAFALPPALEPFYSEHVLRLQGAFQPSDTSRVVAEPPSRTQCGLPEQGVVLCCFNNSYKLN&quot;
		+ &quot;PQSMARMLAVLREVPDSVLWLLSGPGEADARLRAFAHAQGVDAQRLVFMPKLPHPQYLARYRHAD&quot;
		+ &quot;LFLDTHPYNAHTTASDALWTGCPVLTTPGETFAARVAGSLNHHLGLDEMNVADDAAFVAKAVALAS&quot;
		+ &quot;DPAALTALHARVDVLRRESGVFEMDGFADDFGALLQALARRHGWLGI\r\n&quot;
		+ &quot;\r\n&quot;
		+ &quot;&gt;Bar\r\n&quot;
		+ &quot;MGDTTAGEMAVQRGLALHQQRHAEAAVLLQQASDAAPEHPGIALWLHALEDAGQAEAAAAYTRAH&quot;
		+ &quot;QLLPEEPYITAQLLNAVAQGVGAVEPFAFLSEDASAAESVRPLAPTRVRSKGPLRVGFVSNGFGA&quot;
		+ &quot;HPTGLLTVALFEALQRRQPDLQMHLFATSGDDGSTLRTRLAQASTLHDVTALGHLATAKHIRHHG&quot;
		+ &quot;IDLLFDLRGWGGGGRPEVFALRPAPVQVNWLAYPGTSGAPWMDYVLGDAFALPPALEPFYSEHVL&quot;
		+ &quot;RLQGAFQPSDTSRVVAEPPSRTQCGLPEQGVVLCCFNNSYKLNPQSMARMLAVLREVPDSVLWLL&quot;
		+ &quot;SGPGEADARLRAFAHAQGVDAQRLVFMPKLPHPQYLARYRHADLFLDTHPYNAHTTASDALWTGC&quot;
		+ &quot;PVLTTPGETFAARVAGSLNHHLGLDEMNVADDAAFVAKAVALASDPAALTALHARVDVLRRESGV&quot;
		+ &quot;FEMDGFADDFGALLQALARRHGWLGI\r\n&quot;
		+ &quot;\r\n&quot;
		+ &quot;&gt;Friends\r\n&quot;
		+ &quot;MTADGPRELLQLRAAVRHRPQDVAWLMLADAELGMGDTTAGEMAVQRGLALHPGHPEAVARLGRV&quot;
		+ &quot;RWTQQRHAEAAVLLQQASDAAPEHPGIALWLGHALEDHQLLPEEPYITAQLDVLSAQVRAAVAQG&quot;
		+ &quot;VGAVEPFAFLSEDASAAEQLACARTRAQAIAASVRPLAPTRVRSKGPLRVGFVSNGFGAHPTGLL&quot;
		+ &quot;TVALFEALQRRQPDLQMHLFATSGDDGSTLRTRLAQASTLHDVTALGHLATAKHIRHHGIDLLFD&quot;
		+ &quot;LRGWGGGGRPEVFALRPAPVQVNWLAYPGTSGAPWMDYVLGDAFALPPALEPFYSEHVLRLQGAF&quot;
		+ &quot;QPSDTSRVVAEPPSRTQCGLPEQGVVLCCFNNSYKLNPQSMARMLAVLREVPDSVLWLLSGPGEA&quot;
		+ &quot;DARLRAFAHAQGVDAQRLVFMPKLPHPQYLARYRHADLFLDTHPYNAHTTASDALWTGCPVLTTP&quot;
		+ &quot;GETFAARVAGSLNHHLGLDEMNVADDAAFVAKAVALASDPAALTALHARVDVLRRESI&quot;;

public static void main(String[] args) throws UnsupportedRuntimeException,
		LimitExceededException, JobSubmissionException,
		WrongParameterException, FileNotFoundException, IOException,
		ResultNotAvailableException, InterruptedException {

	String qualifiedServiceName = &quot;http://msa.data.compbio/01/01/2010/&quot;;

	/* Make a URL pointing to web service WSDL */
	URL url = new URL(&quot;http://www.compbio.dundee.ac.uk/jabaws/ClustalWS?wsdl&quot;);

	/*
	 * If you are making a client that connects to different web services
	 * you can use something like this:
	 */
	// URL url = new URL(host + &quot;/&quot; + Services.ClustalWS.toString() +
	// &quot;?wsdl&quot;);

	QName qname = new QName(qualifiedServiceName, &quot;ClustalWS&quot;);
	Service serv = Service.create(url, qname);
	/*
	 * Multiple sequence alignment interface for Clustal web service
	 * instance
	 */
	MsaWS msaws = serv.getPort(new QName(qualifiedServiceName, &quot;ClustalWS&quot;
			+ &quot;Port&quot;), MsaWS.class);

	/* Get the list of available presets */
	PresetManager presetman = msaws.getPresets();

	/* Get the Preset object by preset name */
	Preset preset = presetman
			.getPresetByName(&quot;Disable gap weighting (Speed-oriented)&quot;);

	/*
	 * Load sequences in FASTA format from the file You can use something
	 * like new FileInputStream(&lt;filename&gt;) to load sequence from the file
	 */
	List&lt;FastaSequence&gt; fastalist = SequenceUtil
			.readFasta(new ByteArrayInputStream(input.getBytes()));

	/*
	 * Submit loaded sequences for an alignment using preset. The job
	 * identifier is returned by this method, you can retrieve the results
	 * with it sometime later.
	 */
	String jobId = msaws.presetAlign(fastalist, preset);

	/* This method will block for the duration of the calculation */
	Alignment alignment = msaws.getResult(jobId);

	/*
	 * This is a better way of obtaining results, it does not involve
	 * holding the connection open for the duration of the calculation,
	 * Besides, as the University of Dundee public server will reset the
	 * connection after 10 minutes of idling, this is the only way to obtain
	 * the results of long running task from our public server.
	 */
	// while (msaws.getJobStatus(jobId) != JobStatus.FINISHED) {
	// Thread.sleep(1000); // wait a second, then recheck the status
	// }

	/* Output the alignment to standard out */
	System.out.println(alignment);

	// Alternatively, you can record retrieved alignment into the file in
	// ClustalW format

	// ClustalAlignmentUtil.writeClustalAlignment(new FileOutputStream(
	// &quot;output.al&quot;), alignment);

}
}
</code></pre>
				<p>For a more detailed description of all available types and their functions please
					refer to the <a href="dm_javadoc/index.html">data model javadoc</a>.
				</p>
				<p class="text-right">
					<a href="#">Back to top <i class="fa fa-arrow-up" aria-hidden="true"></i></a>
				</p>
			</div>
		</div>
	</div>
</div>
<div class="row" id="buildart">
	<div class="col-md-12">
		<div class="panel panel-default">
			<div class="panel panel-heading">
				<h1 class="panel-title">Building web services artifacts</h1>
			</div>
			<div class="panel-body">
				<p class="justify">
					JABAWS are the standard <a href="http://jax-ws.java.net/">JAX-WS</a> SOAP web
					services, which are <a href="http://www.ws-i.org/">WS-I</a>
					basic profile compatible. This means that you could use whatever tool your
					language has to work with web services. Below is how you can
					generate portable artifacts to work with JABAWS from Java. However if
					programming in Java, we recommend using our  client library as
					it provides a handful of useful methods in addition to plain data types.
				</p>
				<pre><code class="bash">wsimport -keep http://www.compbio.dundee.ac.uk/jabaws/ClustalWS?wsdl</code></pre>
			</div>
		</div>
	</div>
</div>

<jsp:include page="template_footer.jsp" />